@@ -18,12 +18,10 @@
 package extension
 
 import (
-	"github.com/apache/dubbo-go/protocol"
+	"dubbo.apache.org/dubbo-go/v3/protocol"
 )
 
-var (
-	protocols = make(map[string]func() protocol.Protocol)
-)
+var protocols = make(map[string]func() protocol.Protocol)
 
 // SetProtocol sets the protocol extension with @name
 func SetProtocol(name string, v func() protocol.Protocol) {
