@@ -26,6 +26,8 @@ import (
 )
 
 import (
+	"github.com/dubbogo/gost/log/logger"
+
 	"github.com/knadh/koanf"
 
 	"github.com/pkg/errors"
@@ -33,8 +35,7 @@ import (
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
-	"dubbo.apache.org/dubbo-go/v3/common/file"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
+	"dubbo.apache.org/dubbo-go/v3/common/constant/file"
 )
 
 type loaderConf struct {
