@@ -22,8 +22,13 @@ import (
 )
 
 import (
+	getty "github.com/apache/dubbo-getty"
+
 	"github.com/creasty/defaults"
 
+	"github.com/dubbogo/gost/encoding/yaml"
+	"github.com/dubbogo/gost/log/logger"
+
 	"github.com/natefinch/lumberjack"
 
 	"go.uber.org/zap"
@@ -32,8 +37,6 @@ import (
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
-	"dubbo.apache.org/dubbo-go/v3/common/yaml"
 )
 
 type ZapConfig struct {
@@ -93,6 +96,7 @@ func (lc *LoggerConfig) Init() error {
 	}
 	lc.ZapConfig.setZapConfig(logConf.ZapConfig)
 	logger.InitLogger(logConf)
+	getty.SetLogger(logger.GetLogger())
 	return nil
 }
 
