@@ -25,28 +25,24 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-func TestMetadataReportConfig_ToUrl(t *testing.T) {
-	GetBaseConfig().Remotes["mock"] = &RemoteConfig{
-		Address:    "127.0.0.1:2181",
-		Username:   "test",
-		Password:   "test",
-		TimeoutStr: "3s",
-	}
-	metadataReportConfig := MetadataReportConfig{
-		Protocol:  "mock",
-		RemoteRef: "mock",
-		Params: map[string]string{
-			"k": "v",
-		},
-	}
-	url, error := metadataReportConfig.ToUrl()
-	assert.NoError(t, error)
-	assert.Equal(t, "mock", url.Protocol)
-	assert.Equal(t, "127.0.0.1:2181", url.Location)
-	assert.Equal(t, "127.0.0.1", url.Ip)
-	assert.Equal(t, "2181", url.Port)
-	assert.Equal(t, "test", url.Username)
-	assert.Equal(t, "test", url.Password)
-	assert.Equal(t, "v", url.GetParam("k", ""))
-	assert.Equal(t, "mock", url.GetParam("metadata", ""))
+import (
+	"dubbo.apache.org/dubbo-go/v3/common/constant"
+)
+
+func TestNewMetadataReportConfigBuilder(t *testing.T) {
+	config := NewMetadataReportConfigBuilder().
+		SetProtocol("nacos").
+		SetAddress("127.0.0.1:8848").
+		SetUsername("nacos").
+		SetPassword("123456").
+		SetTimeout("10s").
+		SetGroup("dubbo").
+		Build()
+
+	assert.Equal(t, config.IsValid(), true)
+	assert.Equal(t, config.Prefix(), constant.MetadataReportPrefix)
+
+	url, err := config.ToUrl()
+	assert.NoError(t, err)
+	assert.Equal(t, url.GetParam(constant.TimeoutKey, "3s"), "10s")
 }
