@@ -25,7 +25,10 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-func TestGetMetricConfig(t *testing.T) {
-	empty := GetMetricConfig()
-	assert.NotNil(t, empty)
+func TestMetricConfigBuilder(t *testing.T) {
+	config := NewMetricConfigBuilder().Build()
+	err := config.Init()
+	assert.NoError(t, err)
+	reporterConfig := config.ToReporterConfig()
+	assert.Equal(t, string(reporterConfig.Mode), "pull")
 }
