@@ -25,6 +25,8 @@ import (
 import (
 	hessian "github.com/apache/dubbo-go-hessian2"
 
+	"github.com/dubbogo/gost/log/logger"
+
 	"github.com/knadh/koanf"
 
 	perrors "github.com/pkg/errors"
@@ -36,7 +38,6 @@ import (
 	"dubbo.apache.org/dubbo-go/v3/common"
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
 	"dubbo.apache.org/dubbo-go/v3/common/extension"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
 	"dubbo.apache.org/dubbo-go/v3/config_center"
 	"dubbo.apache.org/dubbo-go/v3/metadata/service/exporter"
 )
