@@ -22,12 +22,13 @@ import (
 )
 
 import (
+	"github.com/dubbogo/gost/encoding/yaml"
+
 	"github.com/stretchr/testify/assert"
 )
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
-	"dubbo.apache.org/dubbo-go/v3/common/yaml"
 	"dubbo.apache.org/dubbo-go/v3/config_center"
 )
 
