@@ -23,14 +23,14 @@ import (
 )
 
 import (
-	"github.com/apache/dubbo-go/common"
-	"github.com/apache/dubbo-go/common/constant"
+	"dubbo.apache.org/dubbo-go/v3/common"
+	"dubbo.apache.org/dubbo-go/v3/common/constant"
 )
 
 func TestOnlyLogRejectedExecutionHandler_RejectedExecution(t *testing.T) {
 	handler := GetOnlyLogRejectedExecutionHandler()
 	invokeUrl := common.NewURLWithOptions(
 		common.WithParams(url.Values{}),
-		common.WithParamsValue(constant.INTERFACE_KEY, "methodName"))
+		common.WithParamsValue(constant.InterfaceKey, "methodName"))
 	handler.RejectedExecution(invokeUrl, nil)
 }
