@@ -29,6 +29,8 @@ import (
 import (
 	"github.com/afex/hystrix-go/hystrix"
 
+	"github.com/dubbogo/gost/log/logger"
+
 	perrors "github.com/pkg/errors"
 
 	"gopkg.in/yaml.v2"
@@ -37,7 +39,6 @@ import (
 import (
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
 	"dubbo.apache.org/dubbo-go/v3/common/extension"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
 	"dubbo.apache.org/dubbo-go/v3/config"
 	"dubbo.apache.org/dubbo-go/v3/filter"
 	"dubbo.apache.org/dubbo-go/v3/protocol"
