@@ -26,6 +26,8 @@ import (
 import (
 	hessian2 "github.com/apache/dubbo-go-hessian2"
 
+	"github.com/dubbogo/gost/log/logger"
+
 	"github.com/pkg/errors"
 
 	"google.golang.org/grpc/connectivity"
@@ -33,7 +35,6 @@ import (
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
 	"dubbo.apache.org/dubbo-go/v3/protocol"
 )
 
