@@ -29,15 +29,13 @@ import (
 )
 
 import (
+	log "github.com/dubbogo/gost/log/logger"
+
 	"github.com/golang/protobuf/proto"
 
 	"google.golang.org/grpc"
 )
 
-import (
-	log "dubbo.apache.org/dubbo-go/v3/common/logger"
-)
-
 type routeGuideServer struct {
 	*RouteGuideProviderBase
 	savedFeatures []*Feature // read-only after initialized
