@@ -23,12 +23,13 @@ import (
 )
 
 import (
+	"github.com/dubbogo/gost/log/logger"
+
 	"go.uber.org/atomic"
 )
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
 )
 
 // MockRegistry is used as mock registry
