@@ -25,6 +25,8 @@ import (
 )
 
 import (
+	"github.com/dubbogo/gost/log/logger"
+
 	perrors "github.com/pkg/errors"
 
 	"github.com/polarismesh/polaris-go/api"
@@ -35,22 +37,16 @@ import (
 	"dubbo.apache.org/dubbo-go/v3/common"
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
 	"dubbo.apache.org/dubbo-go/v3/common/extension"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
-	"dubbo.apache.org/dubbo-go/v3/config_center"
 	"dubbo.apache.org/dubbo-go/v3/registry"
-	"dubbo.apache.org/dubbo-go/v3/remoting"
 	"dubbo.apache.org/dubbo-go/v3/remoting/polaris"
 )
 
-var localIP = ""
-
 const (
 	RegistryConnDelay           = 3
 	defaultHeartbeatIntervalSec = 5
 )
 
 func init() {
-	localIP = common.GetLocalIp()
 	extension.SetRegistry(constant.PolarisKey, newPolarisRegistry)
 }
 
@@ -61,12 +57,10 @@ func newPolarisRegistry(url *common.URL) (registry.Registry, error) {
 		return &polarisRegistry{}, err
 	}
 	pRegistry := &polarisRegistry{
-		consumer:     api.NewConsumerAPIByContext(sdkCtx),
 		provider:     api.NewProviderAPIByContext(sdkCtx),
 		lock:         &sync.RWMutex{},
 		registryUrls: make(map[string]*PolarisHeartbeat),
 		listenerLock: &sync.RWMutex{},
-		watchers:     make(map[string]*PolarisServiceWatcher),
 	}
 
 	return pRegistry, nil
@@ -74,13 +68,11 @@ func newPolarisRegistry(url *common.URL) (registry.Registry, error) {
 
 type polarisRegistry struct {
 	url          *common.URL
-	consumer     api.ConsumerAPI
 	provider     api.ProviderAPI
 	lock         *sync.RWMutex
 	registryUrls map[string]*PolarisHeartbeat
 
 	listenerLock *sync.RWMutex
-	watchers     map[string]*PolarisServiceWatcher
 }
 
 // Register will register the service @url to its polaris registry center.
@@ -155,17 +147,16 @@ func (pr *polarisRegistry) UnRegister(conf *common.URL) error {
 
 // Subscribe returns nil if subscribing registry successfully. If not returns an error.
 func (pr *polarisRegistry) Subscribe(url *common.URL, notifyListener registry.NotifyListener) error {
+	var (
+		newParam    api.WatchServiceRequest
+		newConsumer api.ConsumerAPI
+	)
+
 	role, _ := strconv.Atoi(url.GetParam(constant.RegistryRoleKey, ""))
 	if role != common.CONSUMER {
 		return nil
 	}
 
-	watcher, err := pr.createPolarisWatcherIfAbsent(url)
-
-	if err != nil {
-		return err
-	}
-
 	for {
 		listener, err := NewPolarisListener(url)
 		if err != nil {
@@ -174,15 +165,17 @@ func (pr *polarisRegistry) Subscribe(url *common.URL, notifyListener registry.No
 			continue
 		}
 
-		watcher.AddSubscriber(func(et remoting.EventType, instances []model.Instance) {
-			for i := range instances {
-				instance := instances[i]
-				listener.events.In() <- &config_center.ConfigChangeEvent{ConfigType: et, Value: instance}
-			}
-		})
-
+		watcher, err := newPolarisWatcher(&newParam, newConsumer)
+		if err != nil {
+			logger.Warnf("getwatcher() = err:%v", perrors.WithStack(err))
+			timer := time.NewTimer(time.Duration(RegistryConnDelay) * time.Second)
+			timer.Reset(time.Duration(RegistryConnDelay) * time.Second)
+			continue
+		}
 		for {
+
 			serviceEvent, err := listener.Next()
+
 			if err != nil {
 				logger.Warnf("Selector.watch() = error{%v}", perrors.WithStack(err))
 				listener.Close()
@@ -190,37 +183,11 @@ func (pr *polarisRegistry) Subscribe(url *common.URL, notifyListener registry.No
 			}
 			logger.Infof("update begin, service event: %v", serviceEvent.String())
 			notifyListener.Notify(serviceEvent)
+			watcher.startWatch()
 		}
 	}
 }
 
-func (pr *polarisRegistry) createPolarisWatcherIfAbsent(url *common.URL) (*PolarisServiceWatcher, error) {
-
-	pr.listenerLock.Lock()
-	defer pr.listenerLock.Unlock()
-
-	serviceName := getSubscribeName(url)
-
-	if _, exist := pr.watchers[serviceName]; !exist {
-		subscribeParam := &api.WatchServiceRequest{
-			WatchServiceRequest: model.WatchServiceRequest{
-				Key: model.ServiceKey{
-					Namespace: url.GetParam(constant.PolarisNamespace, constant.PolarisDefaultNamespace),
-					Service:   serviceName,
-				},
-			},
-		}
-
-		watcher, err := newPolarisWatcher(subscribeParam, pr.consumer)
-		if err != nil {
-			return nil, err
-		}
-		pr.watchers[serviceName] = watcher
-	}
-
-	return pr.watchers[serviceName], nil
-}
-
 // UnSubscribe returns nil if unsubscribing registry successfully. If not returns an error.
 func (pr *polarisRegistry) UnSubscribe(url *common.URL, notifyListener registry.NotifyListener) error {
 	// TODO wait polaris support it
@@ -276,12 +243,7 @@ func (pr *polarisRegistry) doHeartbeat(ctx context.Context, ins *api.InstanceReg
 
 // createRegisterParam convert dubbo url to polaris instance register request
 func createRegisterParam(url *common.URL, serviceName string) *api.InstanceRegisterRequest {
-	if len(url.Ip) == 0 {
-		url.Ip = localIP
-	}
-	if len(url.Port) == 0 || url.Port == "0" {
-		url.Port = "80"
-	}
+	common.HandleRegisterIPAndPort(url)
 	port, _ := strconv.Atoi(url.Port)
 
 	metadata := make(map[string]string, len(url.GetParams()))
@@ -309,12 +271,7 @@ func createRegisterParam(url *common.URL, serviceName string) *api.InstanceRegis
 
 // createDeregisterParam convert dubbo url to polaris instance deregister request
 func createDeregisterParam(url *common.URL, serviceName string) *api.InstanceDeRegisterRequest {
-	if len(url.Ip) == 0 {
-		url.Ip = localIP
-	}
-	if len(url.Port) == 0 || url.Port == "0" {
-		url.Port = "80"
-	}
+	common.HandleRegisterIPAndPort(url)
 	port, _ := strconv.Atoi(url.Port)
 	return &api.InstanceDeRegisterRequest{
 		InstanceDeRegisterRequest: model.InstanceDeRegisterRequest{
