@@ -26,6 +26,7 @@ import (
 
 import (
 	gxset "github.com/dubbogo/gost/container/set"
+	"github.com/dubbogo/gost/log/logger"
 
 	perrors "github.com/pkg/errors"
 )
@@ -34,11 +35,11 @@ import (
 	"dubbo.apache.org/dubbo-go/v3/common"
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
 	"dubbo.apache.org/dubbo-go/v3/common/extension"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
 	"dubbo.apache.org/dubbo-go/v3/config"
 	"dubbo.apache.org/dubbo-go/v3/config_center"
 	_ "dubbo.apache.org/dubbo-go/v3/config_center/configurator"
 	"dubbo.apache.org/dubbo-go/v3/protocol"
+	"dubbo.apache.org/dubbo-go/v3/protocol/dubbo3/health"
 	"dubbo.apache.org/dubbo-go/v3/protocol/protocolwrapper"
 	"dubbo.apache.org/dubbo-go/v3/registry"
 	_ "dubbo.apache.org/dubbo-go/v3/registry/directory"
@@ -69,7 +70,7 @@ type registryProtocol struct {
 }
 
 func init() {
-	extension.SetProtocol("registry", GetProtocol)
+	extension.SetProtocol(constant.RegistryProtocol, GetProtocol)
 }
 
 func newRegistryProtocol() *registryProtocol {
@@ -191,6 +192,9 @@ func (proto *registryProtocol) Export(originInvoker protocol.Invoker) protocol.E
 	// export invoker
 	exporter := proto.doLocalExport(originInvoker, providerUrl)
 
+	// update health status
+	health.SetServingStatusServing(registryUrl.Service())
+
 	if len(registryUrl.Protocol) > 0 {
 		// url to registry
 		reg := proto.getRegistry(registryUrl)
@@ -237,9 +241,9 @@ func (proto *registryProtocol) reExport(invoker protocol.Invoker, newUrl *common
 	key := getCacheKey(invoker)
 	if oldExporter, loaded := proto.bounds.Load(key); loaded {
 		wrappedNewInvoker := newInvokerDelegate(invoker, newUrl)
-		oldExporter.(protocol.Exporter).Unexport()
+		oldExporter.(protocol.Exporter).UnExport()
 		proto.bounds.Delete(key)
-		// oldExporter Unexport function unRegister rpcService from the serviceMap, so need register it again as far as possible
+		// oldExporter UnExport function unRegister rpcService from the serviceMap, so need register it again as far as possible
 		if err := registerServiceMap(invoker); err != nil {
 			logger.Error(err.Error())
 		}
@@ -398,7 +402,7 @@ func getSubscribedOverrideUrl(providerUrl *common.URL) *common.URL {
 func (proto *registryProtocol) Destroy() {
 	proto.bounds.Range(func(key, value interface{}) bool {
 		// protocol holds the exporters actually, instead, registry holds them in order to avoid export repeatedly, so
-		// the work for unexport should be finished in protocol.Unexport(), see also config.destroyProviderProtocols().
+		// the work for unexport should be finished in protocol.UnExport(), see also config.destroyProviderProtocols().
 		exporter := value.(*exporterChangeableWrapper)
 		reg := proto.getRegistry(getRegistryUrl(exporter.originInvoker))
 		if err := reg.UnRegister(exporter.registerUrl); err != nil {
@@ -411,7 +415,7 @@ func (proto *registryProtocol) Destroy() {
 		go func() {
 			select {
 			case <-time.After(config.GetShutDown().GetStepTimeout() + config.GetShutDown().GetConsumerUpdateWaitTime()):
-				exporter.Unexport()
+				exporter.UnExport()
 				proto.bounds.Delete(key)
 			}
 		}()
@@ -477,8 +481,8 @@ type exporterChangeableWrapper struct {
 	subscribeUrl  *common.URL
 }
 
-func (e *exporterChangeableWrapper) Unexport() {
-	e.exporter.Unexport()
+func (e *exporterChangeableWrapper) UnExport() {
+	e.exporter.UnExport()
 }
 
 func (e *exporterChangeableWrapper) SetRegisterUrl(registerUrl *common.URL) {
