@@ -19,14 +19,11 @@ package etcdv3
 
 import (
 	gxetcd "github.com/dubbogo/gost/database/kv/etcd/v3"
+	"github.com/dubbogo/gost/log/logger"
 
 	perrors "github.com/pkg/errors"
 )
 
-import (
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
-)
-
 // ValidateClient validates client and sets options
 func ValidateClient(container clientFacade, opts ...gxetcd.Option) error {
 	options := &gxetcd.Options{}
