@@ -24,11 +24,11 @@ import (
 
 import (
 	gxetcd "github.com/dubbogo/gost/database/kv/etcd/v3"
+	"github.com/dubbogo/gost/log/logger"
 )
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common"
-	"dubbo.apache.org/dubbo-go/v3/common/logger"
 )
 
 type clientFacade interface {
