@@ -31,13 +31,14 @@ import (
 )
 
 import (
+	dubbogoLogger "github.com/dubbogo/gost/log/logger"
+
 	"google.golang.org/grpc/balancer"
 	"google.golang.org/grpc/balancer/base"
 
 	"google.golang.org/grpc/connectivity"
 
 	"google.golang.org/grpc/credentials"
-	"google.golang.org/grpc/credentials/tls/certprovider"
 
 	"google.golang.org/grpc/resolver"
 
@@ -45,11 +46,11 @@ import (
 )
 
 import (
-	dubboLogger "dubbo.apache.org/dubbo-go/v3/common/logger"
 	"dubbo.apache.org/dubbo-go/v3/xds/balancer/clusterresolver"
 	"dubbo.apache.org/dubbo-go/v3/xds/balancer/ringhash"
 	"dubbo.apache.org/dubbo-go/v3/xds/client"
 	"dubbo.apache.org/dubbo-go/v3/xds/client/resource"
+	"dubbo.apache.org/dubbo-go/v3/xds/credentials/certprovider"
 	"dubbo.apache.org/dubbo-go/v3/xds/utils/buffer"
 	xdsinternal "dubbo.apache.org/dubbo-go/v3/xds/utils/credentials/xds"
 	"dubbo.apache.org/dubbo-go/v3/xds/utils/grpcsync"
@@ -97,7 +98,7 @@ func (bb) Build(cc balancer.ClientConn, opts balancer.BuildOptions) balancer.Bal
 		done:     grpcsync.NewEvent(),
 		xdsHI:    xdsinternal.NewHandshakeInfo(nil, nil),
 	}
-	b.logger = dubboLogger.GetLogger()
+	b.logger = dubbogoLogger.GetLogger()
 	b.logger.Infof("Created")
 	var creds credentials.TransportCredentials
 	switch {
@@ -172,7 +173,7 @@ type cdsBalancer struct {
 	xdsClient      client.XDSClient      // xDS client to watch Cluster resource.
 	clusterHandler *clusterHandler       // To watch the clusters.
 	childLB        balancer.Balancer
-	logger         dubboLogger.Logger
+	logger         dubbogoLogger.Logger
 	closed         *grpcsync.Event
 	done           *grpcsync.Event
 
